# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.offer_tags_api import OfferTagsApi  # noqa: E501
from allegro_api.rest import ApiException


class TestOfferTagsApi(unittest.TestCase):
    """OfferTagsApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.offer_tags_api.OfferTagsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_assign_tag_to_offer_post(self):
        """Test case for assign_tag_to_offer_post

        Assign tags to an offer  # noqa: E501
        """
        pass

    def test_create_tag_post1(self):
        """Test case for create_tag_post1

        Create a tag  # noqa: E501
        """
        pass

    def test_delete_tag_using_delete(self):
        """Test case for delete_tag_using_delete

        Delete a tag  # noqa: E501
        """
        pass

    def test_list_assigned_offer_tags_get(self):
        """Test case for list_assigned_offer_tags_get

        Get tags assigned to an offer  # noqa: E501
        """
        pass

    def test_list_seller_tags_get1(self):
        """Test case for list_seller_tags_get1

        Get the user's tags  # noqa: E501
        """
        pass

    def test_update_tag_put(self):
        """Test case for update_tag_put

        Modify a tag  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.payments_api import PaymentsApi  # noqa: E501
from allegro_api.rest import ApiException


class TestPaymentsApi(unittest.TestCase):
    """PaymentsApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.payments_api.PaymentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_payment_id_mapping(self):
        """Test case for get_payment_id_mapping

        Mapping of payment identifiers  # noqa: E501
        """
        pass

    def test_get_payments_operation_history(self):
        """Test case for get_payments_operation_history

        Payment operations history  # noqa: E501
        """
        pass

    def test_get_refunded_payments(self):
        """Test case for get_refunded_payments

        Get a list of refunded payments  # noqa: E501
        """
        pass

    def test_initiate_refund(self):
        """Test case for initiate_refund

        Initiate a refund of a payment  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.dispute_list_response import DisputeListResponse  # noqa: E501
from allegro_api.rest import ApiException

class TestDisputeListResponse(unittest.TestCase):
    """DisputeListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DisputeListResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.dispute_list_response.DisputeListResponse()  # noqa: E501
        if include_optional :
            return DisputeListResponse(
                disputes = [
                    allegro_api.models.dispute.Dispute(
                        id = '0', 
                        subject = allegro_api.models.subject.Subject(
                            name = 'nie otrzymałem towaru po wpłacie', ), 
                        status = 'CLOSED', 
                        buyer = allegro_api.models.dispute_user.DisputeUser(
                            id = '0', 
                            login = '0', ), 
                        seller = allegro_api.models.dispute_user.DisputeUser(
                            id = '0', 
                            login = '0', ), 
                        checkout_form = allegro_api.models.dispute_checkout_form.DisputeCheckoutForm(
                            id = '0', 
                            created_at = '2018-02-10T12:12:12Z', ), 
                        message = allegro_api.models.dispute_first_message.DisputeFirstMessage(
                            id = '0', 
                            text = '0', 
                            attachment = allegro_api.models.dispute_attachment.DisputeAttachment(
                                file_name = '0', 
                                url = 'https://upload.allegro.pl/sale/dispute-attachments/eeed0007-4404-4176-a1eb-11d26f056c0d', ), 
                            author = allegro_api.models.dispute_author.DisputeAuthor(
                                login = '0', 
                                role = 'BUYER', ), 
                            created_at = '2018-02-10T12:12:12Z', ), 
                        messages_count = 56, )
                    ]
            )
        else :
            return DisputeListResponse(
        )

    def testDisputeListResponse(self):
        """Test DisputeListResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.badge_campaigns_api import BadgeCampaignsApi  # noqa: E501
from allegro_api.rest import ApiException


class TestBadgeCampaignsApi(unittest.TestCase):
    """BadgeCampaignsApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.badge_campaigns_api.BadgeCampaignsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_badge_applications_get_all(self):
        """Test case for badge_applications_get_all

        [BETA] Get a list of badge applications  # noqa: E501
        """
        pass

    def test_badge_applications_get_one(self):
        """Test case for badge_applications_get_one

        [BETA] Get a badge application details  # noqa: E501
        """
        pass

    def test_badge_campaigns_get_all(self):
        """Test case for badge_campaigns_get_all

        [BETA] Get a list of available badge campaigns  # noqa: E501
        """
        pass

    def test_get_badges(self):
        """Test case for get_badges

        [BETA] Get a list of badges  # noqa: E501
        """
        pass

    def test_post_badges(self):
        """Test case for post_badges

        [BETA] Apply for badge in selected offer  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from allegro_api.api_client import ApiClient
from allegro_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class ProductsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_flat_product_parameters_using_get(self, category_id, **kwargs):  # noqa: E501
        """Get product parameters available in given category  # noqa: E501

        Use this resource to get the list of product parameters available in given category. You can use these parameters to create a new product. <a href=\"../../productization\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_flat_product_parameters_using_get(category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str category_id: The category ID. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CategoryProductParameterList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_flat_product_parameters_using_get_with_http_info(category_id, **kwargs)  # noqa: E501

    def get_flat_product_parameters_using_get_with_http_info(self, category_id, **kwargs):  # noqa: E501
        """Get product parameters available in given category  # noqa: E501

        Use this resource to get the list of product parameters available in given category. You can use these parameters to create a new product. <a href=\"../../productization\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_flat_product_parameters_using_get_with_http_info(category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str category_id: The category ID. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CategoryProductParameterList, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['category_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_flat_product_parameters_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'category_id' is set
        if self.api_client.client_side_validation and ('category_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['category_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `category_id` when calling `get_flat_product_parameters_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'category_id' in local_var_params:
            path_params['categoryId'] = local_var_params['category_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-application', 'bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/categories/{categoryId}/product-parameters', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CategoryProductParameterList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sale_product(self, product_id, **kwargs):  # noqa: E501
        """Get all data of the particular product  # noqa: E501

        Use this resource to retrieve all data of the particular product. <a href=\"../../productization/#details\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sale_product(product_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str product_id: The product identifier. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SaleProductDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_sale_product_with_http_info(product_id, **kwargs)  # noqa: E501

    def get_sale_product_with_http_info(self, product_id, **kwargs):  # noqa: E501
        """Get all data of the particular product  # noqa: E501

        Use this resource to retrieve all data of the particular product. <a href=\"../../productization/#details\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sale_product_with_http_info(product_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str product_id: The product identifier. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SaleProductDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['product_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sale_product" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'product_id' is set
        if self.api_client.client_side_validation and ('product_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['product_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `product_id` when calling `get_sale_product`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'product_id' in local_var_params:
            path_params['productId'] = local_var_params['product_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/products/{productId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SaleProductDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sale_products(self, **kwargs):  # noqa: E501
        """Get search products results  # noqa: E501

        Use this resource to get a list of products according to provided parameters. At least ean or phrase parameter is required. <a href=\"../../productization/#search\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sale_products(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str ean: The EAN values can include EAN, ISBN, and UPC identifier types.
        :param str phrase: Search phrase.
        :param str category_id: The category identifier to filter results.
        :param dict(str, str) dynamic_filters: You can filter and customize your search results to find exactly what you need by applying filters ids and their dictionary values to query according to the flowing pattern: id=value. When the filter definition looks like:   ````   {     \"id\": \"127448\",     \"name\": \"Kolor\",     \"type\": \"SINGLE\",     \"values\": [       {         \"name\": \"biały\",         \"value\": \"2\"       },       {         \"name\": \"czarny\",         \"value\": \"1\" }     ]   }   ```` You can use 'Kolor' filter to query results, i.e.:   * `127448=2` for \"biały\"   * `127448=1` for \"czarny\".
        :param str page_id: A \"cursor\" to the next set of results.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GetSaleProductsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_sale_products_with_http_info(**kwargs)  # noqa: E501

    def get_sale_products_with_http_info(self, **kwargs):  # noqa: E501
        """Get search products results  # noqa: E501

        Use this resource to get a list of products according to provided parameters. At least ean or phrase parameter is required. <a href=\"../../productization/#search\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sale_products_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str ean: The EAN values can include EAN, ISBN, and UPC identifier types.
        :param str phrase: Search phrase.
        :param str category_id: The category identifier to filter results.
        :param dict(str, str) dynamic_filters: You can filter and customize your search results to find exactly what you need by applying filters ids and their dictionary values to query according to the flowing pattern: id=value. When the filter definition looks like:   ````   {     \"id\": \"127448\",     \"name\": \"Kolor\",     \"type\": \"SINGLE\",     \"values\": [       {         \"name\": \"biały\",         \"value\": \"2\"       },       {         \"name\": \"czarny\",         \"value\": \"1\" }     ]   }   ```` You can use 'Kolor' filter to query results, i.e.:   * `127448=2` for \"biały\"   * `127448=1` for \"czarny\".
        :param str page_id: A \"cursor\" to the next set of results.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GetSaleProductsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['ean', 'phrase', 'category_id', 'dynamic_filters', 'page_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sale_products" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and ('ean' in local_var_params and  # noqa: E501
                                                        len(local_var_params['ean']) > 18):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `ean` when calling `get_sale_products`, length must be less than or equal to `18`")  # noqa: E501
        if self.api_client.client_side_validation and ('phrase' in local_var_params and  # noqa: E501
                                                        len(local_var_params['phrase']) > 1024):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `phrase` when calling `get_sale_products`, length must be less than or equal to `1024`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'ean' in local_var_params and local_var_params['ean'] is not None:  # noqa: E501
            query_params.append(('ean', local_var_params['ean']))  # noqa: E501
        if 'phrase' in local_var_params and local_var_params['phrase'] is not None:  # noqa: E501
            query_params.append(('phrase', local_var_params['phrase']))  # noqa: E501
        if 'category_id' in local_var_params and local_var_params['category_id'] is not None:  # noqa: E501
            query_params.append(('category.id', local_var_params['category_id']))  # noqa: E501
        if 'dynamic_filters' in local_var_params and local_var_params['dynamic_filters'] is not None:  # noqa: E501
            query_params.append(('Dynamic filters', local_var_params['dynamic_filters']))  # noqa: E501
        if 'page_id' in local_var_params and local_var_params['page_id'] is not None:  # noqa: E501
            query_params.append(('page.id', local_var_params['page_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/products', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetSaleProductsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def propose_sale_product(self, propose_sale_product_request, **kwargs):  # noqa: E501
        """Propose a product  # noqa: E501

        Use this resource to propose a product.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.propose_sale_product(propose_sale_product_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ProposeSaleProductRequest propose_sale_product_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SaleProductDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.propose_sale_product_with_http_info(propose_sale_product_request, **kwargs)  # noqa: E501

    def propose_sale_product_with_http_info(self, propose_sale_product_request, **kwargs):  # noqa: E501
        """Propose a product  # noqa: E501

        Use this resource to propose a product.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.propose_sale_product_with_http_info(propose_sale_product_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ProposeSaleProductRequest propose_sale_product_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SaleProductDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['propose_sale_product_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method propose_sale_product" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'propose_sale_product_request' is set
        if self.api_client.client_side_validation and ('propose_sale_product_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['propose_sale_product_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `propose_sale_product_request` when calling `propose_sale_product`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'propose_sale_product_request' in local_var_params:
            body_params = local_var_params['propose_sale_product_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/product-proposals', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SaleProductDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.categories_and_parameters_api import CategoriesAndParametersApi  # noqa: E501
from allegro_api.rest import ApiException


class TestCategoriesAndParametersApi(unittest.TestCase):
    """CategoriesAndParametersApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.categories_and_parameters_api.CategoriesAndParametersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_categories_using_get(self):
        """Test case for get_categories_using_get

        Get IDs of Allegro categories  # noqa: E501
        """
        pass

    def test_get_category_using_get1(self):
        """Test case for get_category_using_get1

        Get a category by ID  # noqa: E501
        """
        pass

    def test_get_flat_parameters_using_get2(self):
        """Test case for get_flat_parameters_using_get2

        Get parameters supported by a category  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.checkout_form_delivery_reference import CheckoutFormDeliveryReference  # noqa: E501
from allegro_api.rest import ApiException

class TestCheckoutFormDeliveryReference(unittest.TestCase):
    """CheckoutFormDeliveryReference unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CheckoutFormDeliveryReference
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.checkout_form_delivery_reference.CheckoutFormDeliveryReference()  # noqa: E501
        if include_optional :
            return CheckoutFormDeliveryReference(
                address = allegro_api.models.checkout_form_delivery_address.CheckoutFormDeliveryAddress(
                    first_name = 'Jan', 
                    last_name = 'Kowalski', 
                    street = 'Grunwaldzka 182', 
                    city = 'Poznań', 
                    zip_code = '60-166', 
                    country_code = 'PL', 
                    company_name = '0', 
                    phone_number = '0', ), 
                method = allegro_api.models.checkout_form_delivery_method.CheckoutFormDeliveryMethod(
                    id = '1fa56f79-4b6a-4821-a6f2-ca9c16d5c925', 
                    name = 'Allegro Paczkomaty InPost', ), 
                pickup_point = allegro_api.models.checkout_form_delivery_pickup_point.CheckoutFormDeliveryPickupPoint(
                    id = 'POZ08A', 
                    name = 'Paczkomat POZ08A', 
                    description = 'Stacja paliw BP', 
                    address = allegro_api.models.checkout_form_delivery_pickup_point_address.CheckoutFormDeliveryPickupPointAddress(
                        street = 'Grunwaldzka 108', 
                        zip_code = '60-166', 
                        city = 'Poznań', ), ), 
                cost = allegro_api.models.price.Price(
                    amount = '123.45', 
                    currency = 'PLN', ), 
                time = allegro_api.models.checkout_form_delivery_time.CheckoutFormDeliveryTime(
                    guaranteed = allegro_api.models.checkout_form_delivery_time_guaranteed.CheckoutFormDeliveryTimeGuaranteed(
                        from = '2018-01-01T16:00Z', 
                        to = '2018-01-01T18:00Z', ), ), 
                smart = True, 
                calculated_number_of_packages = 1
            )
        else :
            return CheckoutFormDeliveryReference(
        )

    def testCheckoutFormDeliveryReference(self):
        """Test CheckoutFormDeliveryReference"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.billing_api import BillingApi  # noqa: E501
from allegro_api.rest import ApiException


class TestBillingApi(unittest.TestCase):
    """BillingApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.billing_api.BillingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_billing_entries(self):
        """Test case for get_billing_entries

        Get a list of billing entries  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class OfferListingDtoV1Publication(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'status': 'OfferStatus',
        'starting_at': 'str',
        'started_at': 'str',
        'ending_at': 'str',
        'ended_at': 'str'
    }

    attribute_map = {
        'status': 'status',
        'starting_at': 'startingAt',
        'started_at': 'startedAt',
        'ending_at': 'endingAt',
        'ended_at': 'endedAt'
    }

    def __init__(self, status=None, starting_at=None, started_at=None, ending_at=None, ended_at=None, local_vars_configuration=None):  # noqa: E501
        """OfferListingDtoV1Publication - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._status = None
        self._starting_at = None
        self._started_at = None
        self._ending_at = None
        self._ended_at = None
        self.discriminator = None

        if status is not None:
            self.status = status
        if starting_at is not None:
            self.starting_at = starting_at
        if started_at is not None:
            self.started_at = started_at
        if ending_at is not None:
            self.ending_at = ending_at
        if ended_at is not None:
            self.ended_at = ended_at

    @property
    def status(self):
        """Gets the status of this OfferListingDtoV1Publication.  # noqa: E501


        :return: The status of this OfferListingDtoV1Publication.  # noqa: E501
        :rtype: OfferStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this OfferListingDtoV1Publication.


        :param status: The status of this OfferListingDtoV1Publication.  # noqa: E501
        :type: OfferStatus
        """

        self._status = status

    @property
    def starting_at(self):
        """Gets the starting_at of this OfferListingDtoV1Publication.  # noqa: E501

        The date and time of activation in UTC for a planned listing.  # noqa: E501

        :return: The starting_at of this OfferListingDtoV1Publication.  # noqa: E501
        :rtype: str
        """
        return self._starting_at

    @starting_at.setter
    def starting_at(self, starting_at):
        """Sets the starting_at of this OfferListingDtoV1Publication.

        The date and time of activation in UTC for a planned listing.  # noqa: E501

        :param starting_at: The starting_at of this OfferListingDtoV1Publication.  # noqa: E501
        :type: str
        """

        self._starting_at = starting_at

    @property
    def started_at(self):
        """Gets the started_at of this OfferListingDtoV1Publication.  # noqa: E501

        The actual date and time of activation in UTC.  # noqa: E501

        :return: The started_at of this OfferListingDtoV1Publication.  # noqa: E501
        :rtype: str
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this OfferListingDtoV1Publication.

        The actual date and time of activation in UTC.  # noqa: E501

        :param started_at: The started_at of this OfferListingDtoV1Publication.  # noqa: E501
        :type: str
        """

        self._started_at = started_at

    @property
    def ending_at(self):
        """Gets the ending_at of this OfferListingDtoV1Publication.  # noqa: E501

        The date and time of a planned ending in UTC.  # noqa: E501

        :return: The ending_at of this OfferListingDtoV1Publication.  # noqa: E501
        :rtype: str
        """
        return self._ending_at

    @ending_at.setter
    def ending_at(self, ending_at):
        """Sets the ending_at of this OfferListingDtoV1Publication.

        The date and time of a planned ending in UTC.  # noqa: E501

        :param ending_at: The ending_at of this OfferListingDtoV1Publication.  # noqa: E501
        :type: str
        """

        self._ending_at = ending_at

    @property
    def ended_at(self):
        """Gets the ended_at of this OfferListingDtoV1Publication.  # noqa: E501

        The actual date and time of last ending in UTC.  # noqa: E501

        :return: The ended_at of this OfferListingDtoV1Publication.  # noqa: E501
        :rtype: str
        """
        return self._ended_at

    @ended_at.setter
    def ended_at(self, ended_at):
        """Sets the ended_at of this OfferListingDtoV1Publication.

        The actual date and time of last ending in UTC.  # noqa: E501

        :param ended_at: The ended_at of this OfferListingDtoV1Publication.  # noqa: E501
        :type: str
        """

        self._ended_at = ended_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OfferListingDtoV1Publication):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OfferListingDtoV1Publication):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.dispute_message import DisputeMessage  # noqa: E501
from allegro_api.rest import ApiException

class TestDisputeMessage(unittest.TestCase):
    """DisputeMessage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DisputeMessage
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.dispute_message.DisputeMessage()  # noqa: E501
        if include_optional :
            return DisputeMessage(
                id = '0', 
                text = '0', 
                attachment = allegro_api.models.dispute_attachment.DisputeAttachment(
                    file_name = '0', 
                    url = 'https://upload.allegro.pl/sale/dispute-attachments/eeed0007-4404-4176-a1eb-11d26f056c0d', ), 
                author = allegro_api.models.dispute_message_author.DisputeMessageAuthor(
                    login = '0', 
                    role = 'BUYER', ), 
                created_at = '2018-02-10T12:12:12Z'
            )
        else :
            return DisputeMessage(
                id = '0',
                author = allegro_api.models.dispute_message_author.DisputeMessageAuthor(
                    login = '0', 
                    role = 'BUYER', ),
                created_at = '2018-02-10T12:12:12Z',
        )

    def testDisputeMessage(self):
        """Test DisputeMessage"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.inline_response2001 import InlineResponse2001  # noqa: E501
from allegro_api.rest import ApiException

class TestInlineResponse2001(unittest.TestCase):
    """InlineResponse2001 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineResponse2001
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.inline_response2001.InlineResponse2001()  # noqa: E501
        if include_optional :
            return InlineResponse2001(
                delivery_methods = [
                    allegro_api.models.inline_response_200_1_delivery_methods.inline_response_200_1_deliveryMethods(
                        id = '0', 
                        name = '0', 
                        payment_policy = 'IN_ADVANCE', 
                        allegro_endorsed = True, 
                        shipping_rates_constraints = allegro_api.models.inline_response_200_1_shipping_rates_constraints.inline_response_200_1_shippingRatesConstraints(
                            allowed = True, 
                            max_quantity_per_package = allegro_api.models.inline_response_200_1_shipping_rates_constraints_max_quantity_per_package.inline_response_200_1_shippingRatesConstraints_maxQuantityPerPackage(
                                max = 999999, ), 
                            first_item_rate = allegro_api.models.inline_response_200_1_shipping_rates_constraints_first_item_rate.inline_response_200_1_shippingRatesConstraints_firstItemRate(
                                min = '0.00', 
                                max = '8.99', 
                                currency = 'PLN', ), 
                            next_item_rate = allegro_api.models.inline_response_200_1_shipping_rates_constraints_next_item_rate.inline_response_200_1_shippingRatesConstraints_nextItemRate(
                                min = '0.00', 
                                max = '8.99', 
                                currency = 'PLN', ), 
                            shipping_time = allegro_api.models.inline_response_200_1_shipping_rates_constraints_shipping_time.inline_response_200_1_shippingRatesConstraints_shippingTime(
                                default = allegro_api.models.inline_response_200_1_shipping_rates_constraints_shipping_time_default.inline_response_200_1_shippingRatesConstraints_shippingTime_default(
                                    from = 'PT24H', 
                                    to = 'PT48H', ), 
                                customizable = True, ), ), )
                    ]
            )
        else :
            return InlineResponse2001(
        )

    def testInlineResponse2001(self):
        """Test InlineResponse2001"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.offer_management_api import OfferManagementApi  # noqa: E501
from allegro_api.rest import ApiException


class TestOfferManagementApi(unittest.TestCase):
    """OfferManagementApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.offer_management_api.OfferManagementApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_change_publication_status_using_put(self):
        """Test case for change_publication_status_using_put

        Batch offer publish / unpublish  # noqa: E501
        """
        pass

    def test_create_change_price_command_using_put(self):
        """Test case for create_change_price_command_using_put

        Modify the Buy Now price in an offer  # noqa: E501
        """
        pass

    def test_create_offer_using_post(self):
        """Test case for create_offer_using_post

        Create a draft offer  # noqa: E501
        """
        pass

    def test_delete_offer_using_delete(self):
        """Test case for delete_offer_using_delete

        Delete a draft offer  # noqa: E501
        """
        pass

    def test_get_publication_report_using_get(self):
        """Test case for get_publication_report_using_get

        Publish command summary  # noqa: E501
        """
        pass

    def test_get_publication_tasks_using_get(self):
        """Test case for get_publication_tasks_using_get

        Publish command detailed report  # noqa: E501
        """
        pass

    def test_update_offer_using_put(self):
        """Test case for update_offer_using_put

        Complete a draft offer or edit an offer  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.initialize_refund import InitializeRefund  # noqa: E501
from allegro_api.rest import ApiException

class TestInitializeRefund(unittest.TestCase):
    """InitializeRefund unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InitializeRefund
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.initialize_refund.InitializeRefund()  # noqa: E501
        if include_optional :
            return InitializeRefund(
                payment = allegro_api.models.refund_payment.RefundPayment(
                    id = 'a6bee8b2-8b4e-11e9-8918-07b31163120a', ), 
                reason = 'REFUND', 
                line_items = [
                    allegro_api.models.refund_line_item.RefundLineItem(
                        id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', 
                        type = 'QUANTITY', 
                        quantity = 5, 
                        value = allegro_api.models.refund_line_item_value.RefundLineItem_value(
                            amount = '0', 
                            currency = '0', ), )
                    ], 
                delivery = allegro_api.models.initialize_refund_delivery.InitializeRefund_delivery(
                    value = null, ), 
                overpaid = allegro_api.models.initialize_refund_overpaid.InitializeRefund_overpaid(
                    value = null, ), 
                surcharges = [
                    allegro_api.models.payments_surcharge.PaymentsSurcharge(
                        id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', 
                        value = null, )
                    ], 
                additional_services = allegro_api.models.initialize_refund_additional_services.InitializeRefund_additionalServices(
                    value = null, )
            )
        else :
            return InitializeRefund(
                payment = allegro_api.models.refund_payment.RefundPayment(
                    id = 'a6bee8b2-8b4e-11e9-8918-07b31163120a', ),
                reason = 'REFUND',
        )

    def testInitializeRefund(self):
        """Test InitializeRefund"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
